==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/script/main.scm <==
;Liquid War 6 is a unique multiplayer wargame.
;Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
;
;This program is free software; you can redistribute it and/or
;modify it under the terms of the GNU General Public License
;as published by the Free Software Foundation; either version 2
;of the License, or (at your option) any later version.
;
;This program is distributed in the hope that it will be useful,
;but WITHOUT ANY WARRANTY; without even the implied warranty of
;MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;GNU General Public License for more details.
;
;You should have received a copy of the GNU General Public License
;along with this program; if not, write to the Free Software
;Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
;
;Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
;Contact author        : ufoot@ufoot.org

(define lw6-main 
  (lambda () 
    (begin
      (load "backend.scm")
      (load "clear.scm")
      (load "config.scm")
      (load "console.scm")
      (load "demo.scm")
      (load "display.scm")
      (load "game.scm")
      (load "io.scm")
      (load "local-game.scm")
      (load "log.scm")
      (load "logic.scm")
      (load "loop.scm")
      (load "map.scm")
      (load "menu-engine.scm")
      (load "menu.scm")
      (load "mouse.scm")
      (load "preview.scm")
      (load "quick-start.scm")
      (load "sound.scm")
      (load "style.scm")

      (c-lw6cfg-init)
      (lw6-load-config)
      (if (lw6-gfx-backend-exists?)
	  (begin
	    (c-lw6gfx-create-backend (lw6-get-default-gfx-backend))
	    (c-lw6gfx-init (lw6-config-get-number "width") (lw6-config-get-number "height") (lw6-config-is-true? "fullscreen") 0)
	    (if (lw6-snd-backend-exists?)
		(begin
		  (c-lw6snd-create-backend (lw6-get-default-snd-backend))
		  (c-lw6snd-init 0.5 0.5)
		  )
		)
	    (c-lw6con-init)
	    (lw6-console) ; usefull when piping commands at startup
	    (lw6-init-game-globals)
	    (lw6-play-sound-splash)
	    (lw6-game-loop)
	    (lw6-clear)
	    (c-lw6gfx-quit)
	    (c-lw6gfx-destroy-backend)
	    (c-lw6snd-quit)
	    (c-lw6snd-destroy-backend)
	    (c-lw6con-quit)
	    (lw6-save-config)
	    (c-lw6cfg-quit)
	    )
	  (begin
	    (lw6-log-info (_ "no graphical backend found, game can only run in pure server/console mode"))
	    (lw6-log-warning (_ "server mode not implemented yet"))
	    )
	  )
      )
    )
  )

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/script/main.scm <==
;Liquid War 6 is a unique multiplayer wargame.
;Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
;
;This program is free software; you can redistribute it and/or modify
;it under the terms of the GNU General Public License as published by
;the Free Software Foundation, either version 3 of the License, or
;(at your option) any later version.
;
;This program is distributed in the hope that it will be useful,
;but WITHOUT ANY WARRANTY; without even the implied warranty of
;MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;GNU General Public License for more details.
;
;You should have received a copy of the GNU General Public License
;along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;
;Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
;Contact author        : ufoot@ufoot.org

(define lw6-main 
  (lambda () 
    (begin
      (load "backend.scm")
      (load "clear.scm")
      (load "config.scm")
      (load "console.scm")
      (load "demo.scm")
      (load "display.scm")
      (load "game.scm")
      (load "io.scm")
      (load "local-game.scm")
      (load "log.scm")
      (load "logic.scm")
      (load "loop.scm")
      (load "map.scm")
      (load "menu-engine.scm")
      (load "menu.scm")
      (load "mouse.scm")
      (load "net.scm")
      (load "preview.scm")
      (load "quick-start.scm")
      (load "server.scm")
      (load "sound.scm")
      (load "style.scm")

      (c-lw6cfg-init)
      (lw6-load-config)
      (c-lw6net-init)
      (if (lw6-gfx-backend-exists?)
	  (begin
	    (c-lw6gfx-create-backend (lw6-get-default-gfx-backend))
	    (c-lw6gfx-init (lw6-config-get-number "width") (lw6-config-get-number "height") (lw6-config-is-true? "fullscreen") 0)
	    (if (lw6-snd-backend-exists?)
		(begin
		  (c-lw6snd-create-backend (lw6-get-default-snd-backend))
		  (c-lw6snd-init 0.5 0.5)
		  )
		)
	    (lw6-play-sound-splash)
 	    (lw6-init-game-globals)
	    (lw6-server-start)
	    (c-lw6con-init)
	    (lw6-console) ; usefull when piping commands at startup
	    (lw6-game-loop)
	    (c-lw6con-quit)
	    (lw6-save-config)
	    (lw6-server-stop)
	    (lw6-clear)
	    (c-lw6snd-quit)
	    (c-lw6snd-destroy-backend)
	    (c-lw6gfx-quit)
	    (c-lw6gfx-destroy-backend)
	    (c-lw6net-quit)
	    (c-lw6cfg-quit)
	    )
	  (begin
	    (lw6-log-info (_ "no graphical backend found, game can only run in pure server/console mode"))
	    (lw6-log-warning (_ "server mode not implemented yet"))
	    )
	  )
      )
    )
  )
